/**
 * @file math.cpp
 * @brief General math function definitions.
 *
 * @author Eric Butler (edbutler)
 */

#include "math/math.hpp"

#include "math/color.hpp"

namespace _462 {

void color_to_array( const Color3& color, real_t alpha, unsigned char* arr )
{
    // clamp values
    Color3 tmp = color;
    tmp.clamp_zero_one();
    alpha = std::min( 1.0, std::max( 0.0, alpha ) );

    // convert to ints
    arr[0] = static_cast<unsigned char>( tmp.r * 0xff );
    arr[1] = static_cast<unsigned char>( tmp.g * 0xff );
    arr[2] = static_cast<unsigned char>( tmp.b * 0xff );
    arr[3] = static_cast<unsigned char>( alpha * 0xff );
}

Color3 array_to_color( const unsigned char* arr )
{
    static const real_t inv = 1.0 / 255.0;
    return Color3( arr[0] * inv, arr[1] * inv, arr[2] * inv );
}

} /* _462 */

