/**
 * @file model.cpp
 * @brief Mesh class
 *
 * @author Eric Butler (edbutler)
 *           Zeyang Li (zeyangl)
 */
 
#ifndef _462_SCENE_MESH_HPP_
#define _462_SCENE_MESH_HPP_

#include "math/vector.hpp"

#include <vector>
#include <cassert>

namespace _462 {

/**
 * A mesh of triangles.
 */
class Mesh
{
public:

    struct Vertex
    {
        Vector3 position;
        Vector3 normal;
        Vector2 tex_coord;
    };

    struct Triangle
    {
        // index into the vertex list of the 3 vertices
        size_t vertices[3];
    };

    typedef std::vector< Triangle > TriangleList;
    typedef std::vector< Vertex > VertexList;


    // the filename from which this model is loaded
    std::string filename;

    // The list of all triangles in this model.
    TriangleList triangles;

    // The list of all vertices in this model.
    VertexList vertices;

    Mesh();
    ~Mesh();

    /**
     * Loads the model and creates a lists for vertex arrays.
     * @param load_gldata If true, also creates arrays for GL rendering.
     */
    bool load_mesh( bool load_gldata );

    // renders the mesh
    void render() const;

private:

    bool load_from_obj();

    typedef std::vector< float > FloatList;
    typedef std::vector< unsigned int > IndexList;

    // the vertex data used for GL rendering
    FloatList vertex_data;
    // the index data used for GL rendering
    IndexList index_data;
};


} /* _462 */

#endif /* _462_SCENE_MESH_HPP_ */

