/**
 * @file scene.cpp
 * @brief Function definitions for scenes.
 *
 * @author Eric Butler (edbutler)
 * @author Kristin Siu (kasiu)
 */

#include "scene/scene.hpp"

namespace _462 {


Geometry::Geometry():
    position( Vector3::Zero ),
    orientation( Quaternion::Identity ),
    scale( Vector3::Ones ),
    material( 0 )
{

}

Geometry::~Geometry() { }



PointLight::PointLight():
    position( Vector3::Zero ),
    color( Color3::White )
{
    attenuation.constant = 1;
    attenuation.linear = 0;
    attenuation.quadratic = 0;
}


Scene::Scene()
{
    reset();
}

Scene::~Scene()
{
    reset();
}

void Scene::reset()
{
    for ( GeometryList::iterator i = geometries.begin(); i != geometries.end(); ++i ) {
        delete *i;
    }

    geometries.clear();
    materials.clear();
    meshes.clear();
    point_lights.clear();

    camera = Camera();

    background_color = Color3::Black;
    ambient_light = Color3::Black;
    refractive_index = 1.0;
}

} /* _462 */

